package ru.dbotthepony.kstarbound.world.entities

import com.google.gson.JsonObject
import ru.dbotthepony.kstarbound.Starbound
import ru.dbotthepony.kstarbound.defs.ActorMovementParameters
import ru.dbotthepony.kstarbound.world.World

class PlayerEntity() : DynamicEntity("/") {
	override val movement = EntityActorMovementController(this)

	override val isApplicableForUnloading: Boolean
		get() = false

	override fun defs(): Collection<JsonObject> {
		return emptyList()
	}

	init {
		movement.actorMovementParameters = movement.actorMovementParameters.merge(
			Starbound.gson.fromJson("""
			{
    "standingPoly" : [ [-0.75, -2.0], [-0.35, -2.5], [0.35, -2.5], [0.75, -2.0], [0.75, 0.65], [0.35, 1.22], [-0.35, 1.22], [-0.75, 0.65] ],
    "crouchingPoly" : [ [-0.75, -2.0], [-0.35, -2.5], [0.35, -2.5], [0.75, -2.0], [0.75, -1], [0.35, -0.5], [-0.35, -0.5], [-0.75, -1] ],
    "mass" : 1.6,

    // should keep the player from teleporting through walls
    "maximumCorrection" : 3,
    "maxMovementPerStep" : 0.4,

    "liquidFriction" : 13.0,
    "normalGroundFriction" : 35.0,

    "groundForce" : 250.0,
    "airForce" : 50.0,
    "liquidForce" : 80.0
  }
		""".trimIndent(), ActorMovementParameters::class.java)
		).merge(Starbound.gson.fromJson("""
			{
    "flySpeed" : 0,
    "airFriction" : 0.5,
    "airJumpProfile" : {
      "jumpSpeed" : 23.0,
      "jumpInitialPercentage" : 0.75,
      "jumpHoldTime" : 0.2
    }
  }
		""".trimIndent(), ActorMovementParameters::class.java))
	}
}
